summaryrefslogtreecommitdiff
path: root/java/sql/Array.java
diff options
context:
space:
mode:
authorDavid Gilbert <david.gilbert@object-refinery.com>2006-04-22 06:16:05 +0000
committerDavid Gilbert <david.gilbert@object-refinery.com>2006-04-22 06:16:05 +0000
commit49386b54ba94e937a085f9484371a383d8905f0a (patch)
tree343350801201fcbc169f86b0b26c0dee55ac7e3b /java/sql/Array.java
parentdd5f534c94fe68e4f3aef2fe8a8be0f9035c7d53 (diff)
downloadclasspath-49386b54ba94e937a085f9484371a383d8905f0a.tar.gz
2006-04-22 Carsten Neumann <cn-develop@gmx.net>
* javax/sql/Array.java: Fixed eclipse API doc warnings, named method parameters consistendly, documented some methods. * java/sql/Blob.java: Likewise. * java/sql/CallableStatement.java: Likewise. * java/sql/Clob.java: Likewise. * java/sql/Connection.java: Likewise. * java/sql/DatabaseMetaData.java: Likewise. * java/sql/Date.java: Likewise. * java/sql/Driver.java: Likewise. * java/sql/PreparedStatement.java: Likewise. * java/sql/ResultSet.java: Likewise. * java/sql/ResultSetMetaData.java: Likewise. * java/sql/SQLData.java: Likewise. * java/sql/SQLOutput.java: Likewise. * java/sql/SQLWarning.java: Likewise. * java/sql/Statement.java: Likewise. * java/sql/Time.java: Likewise. * java/sql/Timestamp.java: Likewise. ----------------------------------------------------------------------
Diffstat (limited to 'java/sql/Array.java')
-rw-r--r--java/sql/Array.java26
1 files changed, 13 insertions, 13 deletions
diff --git a/java/sql/Array.java b/java/sql/Array.java
index b9e3a2fb4..c3c42d9cb 100644
--- a/java/sql/Array.java
+++ b/java/sql/Array.java
@@ -1,5 +1,5 @@
/* Array.java -- Interface for accessing SQL array object
- Copyright (C) 1999, 2000, 2002, 2006, Free Software Foundation, Inc.
+ Copyright (C) 1999, 2000, 2002, 2006 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -87,22 +87,22 @@ public interface Array
Object getArray(Map map) throws SQLException;
/**
* Returns a portion of this array starting at <code>index</code>
* into the array and continuing for <code>count</code>
* elements. Fewer than the requested number of elements will be
* returned if the array does not contain the requested number of elements.
* The object returned will be an array of Java objects of
* the appropriate types.
*
- * @param index The offset into this array to start returning elements from.
+ * @param start The index into this array to start returning elements from.
* @param count The requested number of elements to return.
* @return The requested portion of the array.
* @exception SQLException If an error occurs.
*/
- Object getArray(long index, int count) throws SQLException;
+ Object getArray(long start, int count) throws SQLException;
/**
* This method returns a portion of this array starting at <code>index</code>
* into the array and continuing for <code>count</code>
* elements. Fewer than the requested number of elements will be
* returned if the array does not contain the requested number of elements.
@@ -110,13 +110,13 @@ public interface Array
* <code>Map</code> will be used for overriding selected SQL type to
* Java class mappings.
*
- * @param index The offset into this array to start returning elements from.
+ * @param start The index into this array to start returning elements from.
* @param count The requested number of elements to return.
* @param map A mapping of SQL types to Java classes.
* @return The requested portion of the array.
* @exception SQLException If an error occurs.
*/
- Object getArray(long index, int count, Map map) throws SQLException;
+ Object getArray(long start, int count, Map map) throws SQLException;
/**
* Returns the elements in the array as a <code>ResultSet</code>.
@@ -147,24 +147,24 @@ public interface Array
/**
* This method returns a portion of the array as a <code>ResultSet</code>.
- * The returned portion will start at <code>index</code> into the
+ * The returned portion will start at <code>start</code> into the
* array and up to <code>count</code> elements will be returned.
* <p>
* Each row of the result set will have two columns. The first will be
* the index into the array of that row's contents. The second will be
* the actual value of that array element.
*
- * @param index The index into the array to start returning elements from.
+ * @param start The index into the array to start returning elements from.
* @param count The requested number of elements to return.
* @return The requested elements of this array as a <code>ResultSet</code>.
* @exception SQLException If an error occurs.
* @see ResultSet
*/
- ResultSet getResultSet(long index, int count) throws SQLException;
+ ResultSet getResultSet(long start, int count) throws SQLException;
/**
* This method returns a portion of the array as a <code>ResultSet</code>.
- * The returned portion will start at <code>index</code> into the
+ * The returned portion will start at <code>start</code> into the
* array and up to <code>count</code> elements will be returned.
*
* <p> Each row of the result set will have two columns. The first will be
@@ -173,13 +173,13 @@ public interface Array
* will be used to override selected default mappings of SQL types to
* Java classes.</p>
*
- * @param index The index into the array to start returning elements from.
+ * @param start The index into the array to start returning elements from.
* @param count The requested number of elements to return.
* @param map A mapping of SQL types to Java classes.
* @return The requested elements of this array as a <code>ResultSet</code>.
* @exception SQLException If an error occurs.
* @see ResultSet
*/
- ResultSet getResultSet(long index, int count, Map map)
+ ResultSet getResultSet(long start, int count, Map map)
throws SQLException;
}
@@ -87,22 +87,22 @@ public interface Array
Object getArray(Map map) throws SQLException;
/**
- * Returns a portion of this array starting at <code>index</code>
+ * Returns a portion of this array starting at <code>start</code>
* into the array and continuing for <code>count</code>
* elements. Fewer than the requested number of elements will be
@@ -87,22 +87,22 @@ public interface Array
/**
- * This method returns a portion of this array starting at <code>index</code>
+ * This method returns a portion of this array starting at <code>start</code>
* into the array and continuing for <code>count</code>
* elements. Fewer than the requested number of elements will be